export interface ILeftMenuModuleOptions {
    /**
     * Selector to toggle and untoggle the menu
     */
    toggleMenuSelector: string;
    /**
     * Indicates if the state should be persisted
     */
    persistState: boolean;
    /**
     * Days the state is saved
     */
    persistStateForDays?: number;
    /**
     * Optional: Callbacks for events on the menu
     */
    leftMenuCallbacks?: ILeftMenuCallbacks;
}
export interface ILeftMenuCallbacks {
    /**
     * Optional: Called when the menu has begun toggling
     */
    menuBeginToggleCallback?: () => void;
    /**
     * Optional: Called when the menu is done toggling
     */
    menuDidToggleCallback?: () => void;
}
export default class LeftMenuModule {
    private options;
    private $toggleMenuButton;
    private menuHiddenClass;
    private menuHiddenCookieName;
    private menuHiddenManuallyTriggeredCookieName;
    constructor(options: ILeftMenuModuleOptions);
    isSmallScreen(): boolean;
    isMenuVisible(): boolean;
    showMenu(show: boolean): void;
    didManuallyToggleMenu(): boolean;
    private initialiseLeftMenu;
    private triggerMenuBeginToggle;
    private triggerMenuDidToggle;
}
