import { RichTextEditorPlugin } from "./richTextEditor-module";
export interface IMergeFieldModel {
    value: string;
    text: string;
}
export interface IMergefieldPluginOptions {
    /**
     * Optional: The tooltip text for the  button in the toolbar. If not provided, the text will be "Indsæt flettefelt"
     */
    toolbarButtonTooltipText?: string;
    /**
     * The merge fields used by the rich text editor
     */
    mergeFields: IMergeFieldModel[];
    /**
     * Optional: Size of the modal. If not provided, the modal size will be "sm"
     */
    modalSize?: "default" | "sm" | "lg" | "xl";
    /**
     * Optional: Text of the modal title. If not provided, the text will be "Indsæt felter"
     */
    modalTitle?: string;
    /**
     * Optional: Text of the modal accept button. If not provided, the text will be "Indsæt"
     */
    modalAcceptButtonText?: string;
    /**
     * Optional: Text of the modal cancel button. If not provided, the text will be "Annuller"
     */
    modalCancelButtonText?: string;
    /**
     * Optional: The Label above the dropdown with mergefields. If not provided, the text will be "Vælg flettefelt"
     */
    mergefieldsDropdownLabel?: string;
    /**
     * Optional: Placeholder text for the dropdown with mergefields. If not provided, the text will be "Vælg flettefelt"
     */
    mergefieldDropdownPlaceholder?: string;
    /**
     * Optional: Text of the use as link switch. If not provided, the text will be "Indsæt som link"
     */
    useAsLinkLabelSwitch?: string;
    /**
     * Optional: The label above the link text input field. If not provided, the text will be "Link tekst"
     */
    linkTextLabel?: string;
    /**
     * Optional: Placeholder text for the link text input field. If not provided, the text will be "Link tekst"
     */
    linkTextPlaceholder?: string;
    /**
     * Optional: Allow links, if not provided links will not be available
     */
    allowLinks?: boolean;
}
export declare class MergefieldPlugin {
    private $modalElement;
    private $selectElement;
    private settings;
    /** This a plugin for the rich text editor module. It will provide you with the ability to use mergefields in the rich text editor.
     * To override the position of the botton in the toolbar of the rich text editor, use the property customToolbar (in rich text editor module) with the value "mergefields"
     */
    constructor(options: IMergefieldPluginOptions);
    getPlugin(): RichTextEditorPlugin;
    private addDividerAndGetMergeFieldButtonIndex;
    private createCustomButton;
    private initializeModal;
    private setMergeFieldsModalHtml;
    private getMergefield;
    private createLinkHtml;
}
