/**
 * Sticky footer module options
 */
export interface IStickyFooterOptions {
    /**
     * Selector for the container you want to initialize as sticky.
     *
     * Throws an error if empty.
     */
    stickyContainerSelector: string;
    /**
     * Selector for the class that contains the styling for when the sticky footer is sticky.
     *
     * Default value: "sticky-footer-fixed-position"
     */
    fixedPositionClass?: string;
    /**
     * Callback to be called when the sticky footer state changes to sticky.
     */
    didStick?: () => void;
    /**
     * Callback to be called when the sticky footer state changes to unsticky.
     */
    didUnstick?: () => void;
    /**
     * Selector for the element that toggles the left side menu.
     * This ensures that the width of the sticky footer is updated when the menu is hidden and shown.
     */
    leftMenuToggleSelector?: string;
    /**
     * The amount of pixels of the parent container that shoule be visible before showing the sticky footer.
     *
     * E.g. 300: Show the sticky footer when 300 pixels of the parent container is visible.
     *
     * Default value: 300.
     */
    showWhenAmountOfPixelsAreVisible?: number;
}
/**
 * Sticky footer module
 */
export declare class StickyFooterModule {
    /**
     * Constructor for sticky footer, which initialises the module
     */
    constructor(options: IStickyFooterOptions);
    private initModule;
    private bindStickyFooter;
    private updateStickyState;
    private getIsFixedBottomOfStickyContainerInViewport;
    private getIsPlaceholderElementAboveViewportTop;
    private getIsPartOfParentElementVisible;
    private isInViewport;
}
